@@ -4,6 +4,7 @@
 # For full license text, see the LICENSE file in the repo root
 # or https://opensource.org/licenses/BSD-3-Clause
 
+import logging
 from typing import Dict, Optional
 
 import numpy as np
@@ -65,11 +66,16 @@ class CUDADataManager:
     """
 
     def __init__(
-        self, num_agents: int = None, num_envs: int = None, episode_length: int = None
+        self,
+        num_agents: int = None,
+        num_envs: int = None,
+        blocks_per_env: int = 1,
+        episode_length: int = None,
     ):
         """
         :param num_agents: total number of agents for each env
         :param num_envs: total number of example_envs running in parallel
+        :param blocks_per_env: number of blocks to cover one environment
         :param episode_length: the length of one single episode, used for logging in
         general, but in many example_envs, it also sets the duration of a game.
 
@@ -96,6 +102,7 @@ class CUDADataManager:
 
         assert num_agents is not None
         assert num_envs is not None
+        assert blocks_per_env is not None
         assert episode_length is not None
 
         self.add_meta_info(
@@ -103,6 +110,7 @@ class CUDADataManager:
                 "n_agents": num_agents,
                 "episode_length": episode_length,
                 "n_envs": num_envs,
+                "blocks_per_env": blocks_per_env,
             }
         )
         self._add_log_mask_and_push_to_device()
@@ -243,7 +251,7 @@ class CUDADataManager:
         """
         assert isinstance(data, dict)
 
-        print("\nPushing data to device...")
+        logging.info("\nPushing data to device...")
         for key, content in data.items():
             assert (
                 key not in self._host_data
@@ -494,16 +502,17 @@ class CUDADataManager:
         assert name in self._dtype
         return self._dtype[name]
 
-    def _type_warning_helper(self, key: str, old: str, new: str, comment=None):
-        print(
-            f"[WARNING]: CUDADataManager casts the data '{key}' "
-            f"from type {old} to {new}"
+    @staticmethod
+    def _type_warning_helper(key: str, old: str, new: str, comment=None):
+        logging.warning(
+            f"CUDADataManager casts the data '{key}' " f"from type {old} to {new}"
         )
         if comment:
-            print(comment)
+            logging.warning(comment)
 
-    def _shape_info_helper(self, key: str, dtype: str, shape):
-        print(f"- {key:<80}: dtype={dtype:<10}, shape={shape}")
+    @staticmethod
+    def _shape_info_helper(key: str, dtype: str, shape):
+        logging.info(f"- {key:<80}: dtype={dtype:<10}, shape={shape}")
 
     @property
     def host_data(self):
